==> haskell-pointed-5.0.1-70-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pointed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pointed
version: 5.0.1
id: pointed-5.0.1-AsjC8ExFqAC7FG3rlFBVSR
key: pointed-5.0.1-AsjC8ExFqAC7FG3rlFBVSR
license: BSD-3-Clause
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/pointed/
synopsis: Pointed and copointed data
description:
    Pointed and copointed data.
category: Data
abi: d5a5883e68cc718eec77e76462fc344d
exposed: True
exposed-modules:
    Data.Copointed Data.Pointed
import-dirs: /usr/lib/ghc-8.6.4/site-local/pointed-5.0.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/pointed-5.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/pointed-5.0.1
hs-libraries: HSpointed-5.0.1-AsjC8ExFqAC7FG3rlFBVSR
depends:
    base-4.12.0.0 comonad-5.0.4-It8ddWRP4jRldNSP0vxVN
    containers-0.6.0.1
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    kan-extensions-5.2-A8IWRLauLN7AaD8DUig47X
    semigroupoids-5.3.2-4vMxTU7QUhTAhqMRKNGi6Q stm-2.5.0.0
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP transformers-0.5.6.2
    transformers-compat-0.6.2-IT1pgM4Lod5B9rerVXsOk7
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
haddock-interfaces: /usr/share/doc/haskell-pointed/html/pointed.haddock
haddock-html: /usr/share/doc/haskell-pointed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pointed-5.0.1-72-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pointed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pointed
version: 5.0.1
id: pointed-5.0.1-5Gh4nsMi7YqHl9G2lzOKpF
key: pointed-5.0.1-5Gh4nsMi7YqHl9G2lzOKpF
license: BSD-3-Clause
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/pointed/
synopsis: Pointed and copointed data
description:
    Pointed and copointed data.
category: Data
abi: ab4ff33ab6bede7594b347a0552bec78
exposed: True
exposed-modules:
    Data.Copointed Data.Pointed
import-dirs: /usr/lib/ghc-8.6.4/site-local/pointed-5.0.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/pointed-5.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/pointed-5.0.1
hs-libraries: HSpointed-5.0.1-5Gh4nsMi7YqHl9G2lzOKpF
depends:
    base-4.12.0.0 comonad-5.0.4-Eb0V3lKOVycBHSbbmuvoSz
    containers-0.6.0.1
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    kan-extensions-5.2-I3wn4zn5hhI4om6oKrHdw8
    semigroupoids-5.3.2-Bu2F7FQ92OC5GMxlQHm35r stm-2.5.0.0
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP transformers-0.5.6.2
    transformers-compat-0.6.2-IT1pgM4Lod5B9rerVXsOk7
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
haddock-interfaces: /usr/share/doc/haskell-pointed/html/pointed.haddock
haddock-html: /usr/share/doc/haskell-pointed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
